@@ -3,7 +3,7 @@ Example that use memory transport for message produce.
 """
 import time
 
-from kombu import Connection, Exchange, Queue, Consumer
+from kombu import Connection, Consumer, Exchange, Queue
 
 media_exchange = Exchange('media', 'direct')
 video_queue = Queue('video', exchange=media_exchange, routing_key='video')
@@ -19,6 +19,11 @@ connection = Connection("memory:///")
 consumer = Consumer(connection, task_queues, callbacks=[handle_message])
 
 producer = connection.Producer(serializer='json')
-producer.publish({"foo": "bar"}, exchange=media_exchange, routing_key='video', declare=task_queues)
+producer.publish(
+    {"foo": "bar"},
+    exchange=media_exchange,
+    routing_key='video',
+    declare=task_queues,
+)
 consumer.consume()
 connection.drain_events()
