@@ -5,7 +5,7 @@ import re
 import sys
 from collections import namedtuple
 
-__version__ = '5.2.2'
+__version__ = '5.2.4'
 __author__ = 'Ask Solem'
 __contact__ = 'auvipy@gmail.com, ask@celeryproject.org'
 __homepage__ = 'https://kombu.readthedocs.io'
@@ -86,12 +86,6 @@ class module(ModuleType):
         return result
 
 
-# 2.5 does not define __package__
-try:
-    package = __package__
-except NameError:  # pragma: no cover
-    package = 'kombu'
-
 # keep a reference to this module so that it's not garbage collected
 old_module = sys.modules[__name__]
 
@@ -106,7 +100,7 @@ new_module.__dict__.update({
     '__contact__': __contact__,
     '__homepage__': __homepage__,
     '__docformat__': __docformat__,
-    '__package__': package,
+    '__package__': __package__,
     'version_info_t': version_info_t,
     'version_info': version_info,
     'VERSION': VERSION
