@@ -1,19 +1,10 @@
-"""
-kombu.clocks
-============
+"""Logical Clocks and Synchronization."""
 
-Logical Clocks and Synchronization.
-
-"""
-from __future__ import absolute_import
-
-from threading import Lock
 from itertools import islice
 from operator import itemgetter
+from threading import Lock
 
-from .five import zip
-
-__all__ = ['LamportClock', 'timetuple']
+__all__ = ('LamportClock', 'timetuple')
 
 R_CLOCK = '_lamport(clock={0}, timestamp={1}, id={2} {3!r})'
 
@@ -23,12 +14,13 @@ class timetuple(tuple):
 
     Can be used as part of a heap to keep events ordered.
 
-    :param clock:  Event clock value.
-    :param timestamp: Event UNIX timestamp value.
-    :param id: Event host id (e.g. ``hostname:pid``).
-    :param obj: Optional obj to associate with this event.
-
+    Arguments:
+        clock (int):  Event clock value.
+        timestamp (float): Event UNIX timestamp value.
+        id (str): Event host id (e.g. ``hostname:pid``).
+        obj (Any): Optional obj to associate with this event.
     """
+
     __slots__ = ()
 
     def __new__(cls, clock, timestamp, id, obj=None):
@@ -52,9 +44,15 @@ class timetuple(tuple):
             return self[1] < other[1]  # ... or use timestamp
         except IndexError:
             return NotImplemented
-    __gt__ = lambda self, other: other < self
-    __le__ = lambda self, other: not other < self
-    __ge__ = lambda self, other: not self < other
+
+    def __gt__(self, other):
+        return other < self
+
+    def __le__(self, other):
+        return not other < self
+
+    def __ge__(self, other):
+        return not self < other
 
     clock = property(itemgetter(0))
     timestamp = property(itemgetter(1))
@@ -62,7 +60,7 @@ class timetuple(tuple):
     obj = property(itemgetter(3))
 
 
-class LamportClock(object):
+class LamportClock:
     """Lamport's logical clock.
 
     From Wikipedia:
@@ -82,14 +80,13 @@ class LamportClock(object):
     process receives a message, it resynchronizes its logical clock with
     the sender.
 
-    .. seealso::
-
+    See Also:
         * `Lamport timestamps`_
 
         * `Lamports distributed mutex`_
 
-    .. _`Lamport Timestamps`: http://en.wikipedia.org/wiki/Lamport_timestamps
-    .. _`Lamports distributed mutex`: http://bit.ly/p99ybE
+    .. _`Lamport Timestamps`: https://en.wikipedia.org/wiki/Lamport_timestamps
+    .. _`Lamports distributed mutex`: https://bit.ly/p99ybE
 
     *Usage*
 
@@ -98,6 +95,7 @@ class LamportClock(object):
     the time stamp of the incoming message.
 
     """
+
     #: The clocks current value.
     value = 0
 
@@ -107,8 +105,8 @@ class LamportClock(object):
 
     def adjust(self, other):
         with self.mutex:
-            self.value = max(self.value, other) + 1
-            return self.value
+            value = self.value = max(self.value, other) + 1
+            return value
 
     def forward(self):
         with self.mutex:
@@ -116,7 +114,9 @@ class LamportClock(object):
             return self.value
 
     def sort_heap(self, h):
-        """List of tuples containing at least two elements, representing
+        """Sort heap of events.
+
+        List of tuples containing at least two elements, representing
         an event, where the first element is the event's scalar clock value,
         and the second element is the id of the process (usually
         ``"hostname:pid"``): ``sh([(clock, processid, ...?), (...)])``
@@ -128,7 +128,6 @@ class LamportClock(object):
         present.
 
         Will return the latest event.
-
         """
         if h[0][0] == h[1][0]:
             same = []
@@ -145,4 +144,4 @@ class LamportClock(object):
         return str(self.value)
 
     def __repr__(self):
-        return '<LamportClock: {0.value}>'.format(self)
+        return f'<LamportClock: {self.value}>'
