@@ -1,36 +1,25 @@
 """Common Utilities."""
-from __future__ import absolute_import, unicode_literals
 
 import os
 import socket
 import threading
-
 from collections import deque
 from contextlib import contextmanager
 from functools import partial
 from itertools import count
-from uuid import uuid5, uuid4, uuid3, NAMESPACE_OID
+from uuid import NAMESPACE_OID, uuid3, uuid4, uuid5
 
-from amqp import RecoverableConnectionError
+from amqp import ChannelError, RecoverableConnectionError
 
 from .entity import Exchange, Queue
-from .five import bytes_if_py2, range
 from .log import get_logger
 from .serialization import registry as serializers
 from .utils.uuid import uuid
 
-try:
-    from _thread import get_ident
-except ImportError:                             # pragma: no cover
-    try:                                        # noqa
-        from thread import get_ident            # noqa
-    except ImportError:                         # pragma: no cover
-        from dummy_thread import get_ident      # noqa
-
-__all__ = ['Broadcast', 'maybe_declare', 'uuid',
+__all__ = ('Broadcast', 'maybe_declare', 'uuid',
            'itermessages', 'send_reply',
            'collect_replies', 'insured', 'drain_consumer',
-           'eventloop']
+           'eventloop')
 
 #: Prefetch count can't exceed short.
 PREFETCH_COUNT_MAX = 0xFFFF
@@ -48,8 +37,8 @@ def get_node_id():
 
 
 def generate_oid(node_id, process_id, thread_id, instance):
-    ent = bytes_if_py2('%x-%x-%x-%x' % (
-        node_id, process_id, thread_id, id(instance)))
+    ent = '{:x}-{:x}-{:x}-{:x}'.format(
+        node_id, process_id, thread_id, id(instance))
     try:
         ret = str(uuid3(NAMESPACE_OID, ent))
     except ValueError:
@@ -61,7 +50,7 @@ def oid_from(instance, threads=True):
     return generate_oid(
         get_node_id(),
         os.getpid(),
-        get_ident() if threads else 0,
+        threading.get_ident() if threads else 0,
         instance,
     )
 
@@ -79,16 +68,27 @@ class Broadcast(Queue):
         queue (str): By default a unique id is used for the queue
             name for every consumer.  You can specify a custom
             queue name here.
+        unique (bool): Always create a unique queue
+            even if a queue name is supplied.
         **kwargs (Any): See :class:`~kombu.Queue` for a list
             of additional keyword arguments supported.
     """
 
     attrs = Queue.attrs + (('queue', None),)
 
-    def __init__(self, name=None, queue=None, auto_delete=True,
-                 exchange=None, alias=None, **kwargs):
-        queue = queue or 'bcast.{0}'.format(uuid())
-        return super(Broadcast, self).__init__(
+    def __init__(self,
+                 name=None,
+                 queue=None,
+                 unique=False,
+                 auto_delete=True,
+                 exchange=None,
+                 alias=None,
+                 **kwargs):
+        if unique:
+            queue = '{}.{}'.format(queue or 'bcast', uuid())
+        else:
+            queue = queue or f'bcast.{uuid()}'
+        super().__init__(
             alias=alias or name,
             queue=queue,
             name=queue,
@@ -105,15 +105,37 @@ def declaration_cached(entity, channel):
 
 def maybe_declare(entity, channel=None, retry=False, **retry_policy):
     """Declare entity (cached)."""
+    if retry:
+        return _imaybe_declare(entity, channel, **retry_policy)
+    return _maybe_declare(entity, channel)
+
+
+def _ensure_channel_is_bound(entity, channel):
+    """Make sure the channel is bound to the entity.
+
+    :param entity: generic kombu nomenclature, generally an exchange or queue
+    :param channel: channel to bind to the entity
+    :return: the updated entity
+    """
     is_bound = entity.is_bound
+    if not is_bound:
+        if not channel:
+            raise ChannelError(
+                f"Cannot bind channel {channel} to entity {entity}")
+        entity = entity.bind(channel)
+        return entity
+
+
+def _maybe_declare(entity, channel):
+    # _maybe_declare sets name on original for autogen queues
     orig = entity
 
-    if not is_bound:
-        assert channel
-        entity = entity.bind(channel)
+    _ensure_channel_is_bound(entity, channel)
 
     if channel is None:
-        assert is_bound
+        if not entity.is_bound:
+            raise ChannelError(
+                f"channel is None and entity {entity} not bound.")
         channel = entity.channel
 
     declared = ident = None
@@ -123,13 +145,6 @@ def maybe_declare(entity, channel=None, retry=False, **retry_policy):
         if ident in declared:
             return False
 
-    if retry:
-        return _imaybe_declare(entity, declared, ident,
-                               channel, orig, **retry_policy)
-    return _maybe_declare(entity, declared, ident, channel, orig)
-
-
-def _maybe_declare(entity, declared, ident, channel, orig=None):
     if not channel.connection:
         raise RecoverableConnectionError('channel disconnected')
     entity.declare(channel=channel)
@@ -140,11 +155,14 @@ def _maybe_declare(entity, declared, ident, channel, orig=None):
     return True
 
 
-def _imaybe_declare(entity, declared, ident, channel,
-                    orig=None, **retry_policy):
+def _imaybe_declare(entity, channel, **retry_policy):
+    _ensure_channel_is_bound(entity, channel)
+
+    if not entity.channel.connection:
+        raise RecoverableConnectionError('channel disconnected')
+
     return entity.channel.connection.client.ensure(
-        entity, _maybe_declare, **retry_policy)(
-            entity, declared, ident, channel, orig)
+        entity, _maybe_declare, **retry_policy)(entity, channel)
 
 
 def drain_consumer(consumer, limit=1, timeout=None, callbacks=None):
@@ -324,7 +342,7 @@ def insured(pool, fun, args, kwargs, errback=None, on_revive=None, **opts):
         return retval
 
 
-class QoS(object):
+class QoS:
     """Thread safe increment/decrement of a channels prefetch_count.
 
     Arguments:
@@ -403,8 +421,8 @@ class QoS(object):
         if pcount != self.prev:
             new_value = pcount
             if pcount > PREFETCH_COUNT_MAX:
-                logger.warn('QoS: Disabled: prefetch_count exceeds %r',
-                            PREFETCH_COUNT_MAX)
+                logger.warning('QoS: Disabled: prefetch_count exceeds %r',
+                               PREFETCH_COUNT_MAX)
                 new_value = 0
             logger.debug('basic.qos: prefetch_count->%s', new_value)
             self.callback(prefetch_count=new_value)
