@@ -1,32 +1,28 @@
-# -*- coding: utf-8 -*-
-"""
-kombu.mixins
-============
-
-Useful mixin classes.
-
-"""
-from __future__ import absolute_import
+"""Mixins."""
 
 import socket
-
 from contextlib import contextmanager
 from functools import partial
 from itertools import count
 from time import sleep
 
 from .common import ignore_errors
-from .five import range
-from .messaging import Consumer
 from .log import get_logger
-from .utils import cached_property, nested
+from .messaging import Consumer, Producer
+from .utils.compat import nested
 from .utils.encoding import safe_repr
 from .utils.limits import TokenBucket
+from .utils.objects import cached_property
 
-__all__ = ['ConsumerMixin']
+__all__ = ('ConsumerMixin', 'ConsumerProducerMixin')
 
 logger = get_logger(__name__)
-debug, info, warn, error = logger.debug, logger.info, logger.warn, logger.error
+debug, info, warn, error = (
+    logger.debug,
+    logger.info,
+    logger.warning,
+    logger.error
+)
 
 W_CONN_LOST = """\
 Connection to broker lost, trying to re-establish connection...\
@@ -37,7 +33,7 @@ Broker connection error, trying again in %s seconds: %r.\
 """
 
 
-class ConsumerMixin(object):
+class ConsumerMixin:
     """Convenience mixin for implementing consumer programs.
 
     It can be used outside of threads, with threads, or greenthreads
@@ -50,26 +46,24 @@ class ConsumerMixin(object):
     Supporting multiple consumers is important so that multiple
     channels can be used for different QoS requirements.
 
-    **Example**:
+    Example:
+        .. code-block:: python
 
-    .. code-block:: python
+            class Worker(ConsumerMixin):
+                task_queue = Queue('tasks', Exchange('tasks'), 'tasks')
 
+                def __init__(self, connection):
+                    self.connection = None
 
-        class Worker(ConsumerMixin):
-            task_queue = Queue('tasks', Exchange('tasks'), 'tasks'))
+                def get_consumers(self, Consumer, channel):
+                    return [Consumer(queues=[self.task_queue],
+                                     callbacks=[self.on_task])]
 
-            def __init__(self, connection):
-                self.connection = None
+                def on_task(self, body, message):
+                    print('Got task: {0!r}'.format(body))
+                    message.ack()
 
-            def get_consumers(self, Consumer, channel):
-                return [Consumer(queues=[self.task_queue],
-                                 callback=[self.on_task])]
-
-            def on_task(self, body, message):
-                print('Got task: {0!r}'.format(body))
-                message.ack()
-
-    **Additional handler methods**:
+    Methods:
 
         * :meth:`extra_context`
 
@@ -106,7 +100,7 @@ class ConsumerMixin(object):
 
         * :meth:`on_consume_end`
 
-            Handler called after the consumers are cancelled.
+            Handler called after the consumers are canceled.
             Takes arguments ``(connection, channel)``.
 
         * :meth:`on_iteration`
@@ -167,14 +161,14 @@ class ConsumerMixin(object):
     def extra_context(self, connection, channel):
         yield
 
-    def run(self, _tokens=1):
+    def run(self, _tokens=1, **kwargs):
         restart_limit = self.restart_limit
         errors = (self.connection.connection_errors +
                   self.connection.channel_errors)
         while not self.should_stop:
             try:
-                if restart_limit.can_consume(_tokens):
-                    for _ in self.consume(limit=None):  # pragma: no cover
+                if restart_limit.can_consume(_tokens):  # pragma: no cover
+                    for _ in self.consume(limit=None, **kwargs):
                         pass
                 else:
                     sleep(restart_limit.expected_time(_tokens))
@@ -202,7 +196,7 @@ class ConsumerMixin(object):
                     elapsed += safety_interval
                     if timeout and elapsed >= timeout:
                         raise
-                except socket.error:
+                except OSError:
                     if not self.should_stop:
                         raise
                 else:
@@ -234,7 +228,7 @@ class ConsumerMixin(object):
                           on_decode_error=self.on_decode_error)
             with self._consume_from(*self.get_consumers(cls, channel)) as c:
                 yield conn, channel, c
-            debug('Consumers cancelled')
+            debug('Consumers canceled')
             self.on_consume_end(conn, channel)
         debug('Connection closed')
 
@@ -243,9 +237,6 @@ class ConsumerMixin(object):
 
     @cached_property
     def restart_limit(self):
-        # the AttributeError that can be catched from amqplib
-        # poses problems for the too often restarts protection
-        # in Connection.ensure_connection
         return TokenBucket(1)
 
     @cached_property
@@ -255,3 +246,54 @@ class ConsumerMixin(object):
     @cached_property
     def channel_errors(self):
         return self.connection.channel_errors
+
+
+class ConsumerProducerMixin(ConsumerMixin):
+    """Consumer and Producer mixin.
+
+    Version of ConsumerMixin having separate connection for also
+    publishing messages.
+
+    Example:
+        .. code-block:: python
+
+            class Worker(ConsumerProducerMixin):
+
+                def __init__(self, connection):
+                    self.connection = connection
+
+                def get_consumers(self, Consumer, channel):
+                    return [Consumer(queues=Queue('foo'),
+                                     on_message=self.handle_message,
+                                     accept='application/json',
+                                     prefetch_count=10)]
+
+                def handle_message(self, message):
+                    self.producer.publish(
+                        {'message': 'hello to you'},
+                        exchange='',
+                        routing_key=message.properties['reply_to'],
+                        correlation_id=message.properties['correlation_id'],
+                        retry=True,
+                    )
+    """
+
+    _producer_connection = None
+
+    def on_consume_end(self, connection, channel):
+        if self._producer_connection is not None:
+            self._producer_connection.close()
+            self._producer_connection = None
+
+    @property
+    def producer(self):
+        return Producer(self.producer_connection)
+
+    @property
+    def producer_connection(self):
+        if self._producer_connection is None:
+            conn = self.connection.clone()
+            conn.ensure_connection(self.on_connection_error,
+                                   self.connect_max_retries)
+            self._producer_connection = conn
+        return self._producer_connection
