@@ -1,11 +1,11 @@
-import pytest
 import socket
 import warnings
-
+from concurrent.futures import ProcessPoolExecutor, ThreadPoolExecutor
 from unittest.mock import Mock, patch
 
-from kombu import Connection
-from kombu import pidbox
+import pytest
+
+from kombu import Connection, pidbox
 from kombu.exceptions import ContentDisallowed, InconsistencyError
 from kombu.utils.uuid import uuid
 
@@ -339,3 +339,38 @@ class test_Mailbox:
         m = consumer.queues[0].get()
         if m:
             return m.payload
+
+
+GLOBAL_PIDBOX = pidbox.Mailbox('global_unittest_mailbox')
+
+
+def getoid():
+    return GLOBAL_PIDBOX.oid
+
+
+class test_PidboxOid:
+    """Unittests checking oid consistency of Pidbox"""
+
+    def test_oid_consistency(self):
+        """Tests that oid is consistent in single process"""
+        m1 = pidbox.Mailbox('mailbox1')
+        m2 = pidbox.Mailbox('mailbox2')
+        assert m1.oid == m1.oid
+        assert m2.oid == m2.oid
+        assert m1.oid != m2.oid
+
+    def test_subprocess_oid(self):
+        """Tests that subprocess will not share oid with parent process."""
+        oid = GLOBAL_PIDBOX.oid
+        with ProcessPoolExecutor() as e:
+            res = e.submit(getoid)
+            subprocess_oid = res.result()
+        assert subprocess_oid != oid
+
+    def test_thread_oid(self):
+        """Tests that threads will not share oid."""
+        oid = GLOBAL_PIDBOX.oid
+        with ThreadPoolExecutor() as e:
+            res = e.submit(getoid)
+            subprocess_oid = res.result()
+        assert subprocess_oid != oid
