@@ -1,7 +1,8 @@
-import pytest
 import socket
 
-from kombu import Connection, Exchange, Queue, Consumer, Producer
+import pytest
+
+from kombu import Connection, Consumer, Exchange, Producer, Queue
 
 
 class test_MemoryTransport:
