@@ -1,13 +1,9 @@
 import sys
-
 from contextlib import contextmanager
-
 from unittest.mock import patch
 
-from kombu.utils.encoding import (
-    get_default_encoding_file, safe_str,
-    set_default_encoding_file, default_encoding,
-)
+from kombu.utils.encoding import (default_encoding, get_default_encoding_file,
+                                  safe_str, set_default_encoding_file)
 
 
 @contextmanager
